/*********************************************************************
 *
 *    USB Firmware LowPinCountUSB DK with 16F1459 specific code
 *
 *********************************************************************
 * FileName:        lpcudk_16F1459.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC16F1459
 * Compiler:        XC8
 * Company:         HS-Ulm
 *
 * Author       Company     Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * VSK          HS-Ulm      17.04.15
 *
 *		TODO
 *
 *		-	...
 *
 ******************************************************************************/

#if defined (__16F1459)
    #include <pic16f1459.h>
#elif defined(__16F1455)
    #include <pic16f1455.h>
#else
    #warning "Which PIC ???"
#endif

#include "system.h"

/** CONFIGURATION Bits **********************************************/
// PIC16F1459 configuration bit settings:
#if defined (USE_INTERNAL_OSC)	    // Define this in system.h if using the HFINTOSC for USB operation
    // CONFIG1
    #pragma config FOSC = INTOSC    // Oscillator Selection Bits (INTOSC oscillator: I/O function on CLKIN pin)
    #pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
    #pragma config PWRTE = OFF      // Power-up Timer Enable (PWRT disabled)
  #if defined(__DEBUG)
        #pragma config MCLRE  = ON
  #else
        #pragma config MCLRE  = OFF // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
  #endif
    #pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
    #pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
    #pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
    #pragma config IESO = OFF       // Internal/External Switchover Mode (Internal/External Switchover Mode is disabled)
    #pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

    // CONFIG2
    #pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
    #pragma config CPUDIV = NOCLKDIV// CPU System Clock Selection Bit (NO CPU system divide)
    #pragma config USBLSCLK = 48MHz // USB Low SPeed Clock Selection bit (System clock expects 48 MHz, FS/LS USB CLKENs divide-by is set to 8.)
    #pragma config PLLMULT = 3x     // PLL Multipler Selection Bit (3x Output Frequency Selected)
    #pragma config PLLEN = ENABLED  // PLL Enable Bit (3x or 4x PLL Enabled)
    #pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
    #pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
    #pragma config LPBOR = OFF      // Low-Power Brown Out Reset (Low-Power BOR is disabled)
    #pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)
#else
    // CONFIG1
    #pragma config FOSC = HS        // Oscillator Selection Bits (HS Oscillator, High-speed crystal/resonator connected between OSC1 and OSC2 pins)
    #pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
    #pragma config PWRTE = OFF      // Power-up Timer Enable (PWRT disabled)
  #if defined(__DEBUG)
        #pragma config MCLRE  = ON
  #else
        #pragma config MCLRE  = OFF // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
  #endif
    #pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
    #pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
    #pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
    #pragma config IESO = OFF       // Internal/External Switchover Mode (Internal/External Switchover Mode is disabled)
    #pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

    // CONFIG2
    #pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
    #pragma config CPUDIV = NOCLKDIV// CPU System Clock Selection Bit (NO CPU system divide)
    #pragma config USBLSCLK = 48MHz // USB Low SPeed Clock Selection bit (System clock expects 48 MHz, FS/LS USB CLKENs divide-by is set to 8.)
    #pragma config PLLMULT = 4x     // PLL Multipler Selection Bit (4x Output Frequency Selected)
    #pragma config PLLEN = ENABLED  // PLL Enable Bit (3x or 4x PLL Enabled)
    #pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
    #pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
    #pragma config LPBOR = OFF      // Low-Power Brown Out Reset (Low-Power BOR is disabled)
    #pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)
#endif   


/** VARIABLES ******************************************************/


/******************************************************************************
 * Function:        void initADC(void)
 *
 * PreCondition:    None
 * Input:           None
 * Output:          None
 * Side Effects:    None
 *
 * Overview:        
 *
 * Note:
 *
 *****************************************************************************/
void initADC(void)
{
    ADCON1bits.ADPREF = 0b00;
    ADCON1bits.ADCS = 0b110;
    ADCON1bits.ADFM = 1;
#if defined(__16F1459)    
    ADCON0bits.CHS = 0b01010;
#elif defined(__16F1455)
    ADCON0bits.CHS = 0b00011;
#else
    #warning "which PIC ???"
#endif    
    ADCON0bits.ADON = 1;
}

/******************************************************************************
 * Function:        void initSpecialEventTrigger(void)
 *
 * PreCondition:    None
 * Input:           None
 * Output:          None
 * Side Effects:    None
 *
 * Overview:    The special event trigger is used for automatic ADC
 *
 * Note:        NYI ;-)
 *
 *****************************************************************************/
void initSpecialEventTrigger(void)
{
//    OpenTimer1(TIMER_INT_OFF & T1_16BIT_RW & T1_SOURCE_INT &
//            T1_PS_1_8 & T1_OSC1EN_OFF & T1_SYNC_EXT_OFF);
//    T1CONbits.TMR1ON = 0;
////    mCCPTIMER_STOP()
//    T3CONbits.T3CCP1 = 0;       // Timer1 is the clock source for compare ECCP1
//    CCPR1 = 60000;              // 12M (clk) / 8 (TMR1 Prescaler)    -> 25Hz
//    CCP1CONbits.CCP1M = 0b1011; // Compare Mode with Special Event Trigger
}

/** EOF lpcudk_16F1459.c *************************************************/
